function [ker,arg]=kerarg(name,arg)
% KERNELID Returns kernel identifier and adjusted arguments.
%
% Synopsis:
%  [ker,arg]=kerarg(name,arg)
%
% Description:
%  This function serves as an interface between C-code functions
%  using library kernel.c and M-files.
%  The input is a given kernel name and corresponding arguments.
%  The output is the kernel identifier (integer) and kernel argument 
%  adjusted if necesary.
%
%  The kernel names, arguments and their default setting:
%
%                   ID   Name     Default       Definition
%    Linear kernel   0  'linear'  arg=0         a'*b
%    Polynomial      1  'poly'    arg=[1,1]     (a'*b+arg[2])^arg[1]
%    RBF             2  'rbf'     arg=1         exp(-0.5*||a-b||^2/arg[1]^2)
%    Sigmoidal       3  'sigmoid' arg=[1,1]     tanh(arg[1]*(a'*b)+arg[2])
%
% Input:
%  name [string] Kernel name.
%  arg [...] Kernel argument.
%  
% Output:
%  id [int] Kernel identifier.
%  arg [...] Kernel argument.
%

% About: Statistical Pattern Recognition Toolbox
% (C) 1999-2003, Written by Vojtech Franc and Vaclav Hlavac
% <a href="http://www.cvut.cz">Czech Technical University Prague</a>
% <a href="http://www.feld.cvut.cz">Faculty of Electrical Engineering</a>
% <a href="http://cmp.felk.cvut.cz">Center for Machine Perception</a>

% Modifications:
%  4-June-2003, VF

switch lower(name)
  case 'linear' 
    ker = 0; arg = 0;
  case 'poly'
    ker = 1;
    if isempty(arg), arg = [1,1]; 
    elseif length(arg) < 2, arg=[arg,1]; end
  case 'rbf'
    ker = 2;
    if isempty(arg), arg = 1; end
  case 'sigmoid'
    ker = 3;
    if isempty(arg), arg = [1,1]; end
  otherwise
    error('Unknown kernel identifier.');
end

return;

