function K = kernel(varargin)
% KERNEL Computes kernel matrix.
%
% Synopsis:
%  K = kernel( X, ker, arg )
%  K = kernel( X1, X2, ker, arg )
%
% Description:
%  K = kernel( X, ker, arg ) returns matrix K [n x n] where n is
%  number of input data n=size(X,2). The matrix K contains 
%  values of kernel function for given data X, i.e., 
%  K(i,j)=k(X(:,i),X(:,j)), i,j=1,...,n.
%
%  K = kernel( X1, X2, ker, arg ) return matrix [n x m] where n
%  is number of data in X1 and X2, i.e.,  n=size(X1,2) and 
%  m=size(X2,2). The kernel matrix K contains values of kernel 
%  functions for given data X1 and X2, i.e.,
%  K(i,j)=k(X1(:,i),X2(:,j)), i=1,...,n, j=1,...,m.
% 
%  The kernel names, arguments and their default setting:
%
%                    Name      Default       Definition
%    Linear kernel   'linear'  arg=0         a'*b
%    Polynomial      'poly'    arg=[1,1]     (a'*b+arg[2])^arg[1]
%    RBF             'rbf'     arg=1         exp(-0.5*||a-b||^2/arg[1]^2)
%    Sigmoidal       'sigmoid' arg=[1,1]     tanh(arg[1]*(a'*b)+arg[2])
%
%  This function is only interface for C-code. To make executable
%  file run
%    mex kernelccode.c kernel.c
%
% Input:
%  X [dim x n] Input data.
% or
%  X1 [dim x n], X2 [dim x m] Input data.
%  ker [string] Kernel identifier.
%  arg [...] Argument of selected kernel.
%
% Output:
%  K [n x n] Kernel matrix.
% or
%  K [n x m] Kernel matrix.
%

% About: Statistical Pattern Recognition Toolbox
% (C) 1999-2003, Written by Vojtech Franc and Vaclav Hlavac
% <a href="http://www.cvut.cz">Czech Technical University Prague</a>
% <a href="http://www.feld.cvut.cz">Faculty of Electrical Engineering</a>
% <a href="http://cmp.felk.cvut.cz">Center for Machine Perception</a>

% Modifications:
%  4-June-2003, VF
%  21-jan-2003, VF
%  13-sep-2002, VF
%  21-October-2001, V.Franc
%  2-October-2001, V.Franc, created.

if nargin ==3,
  [ker,arg]=kerarg(varargin{2}, varargin{3});
  K = kernelccode( varargin{1}, ker, arg );
else
  [ker,arg]=kerarg(varargin{3}, varargin{4});
  K = kernelccode( varargin{1}, varargin{2}, ker, arg);
end

return;
